==> jc-1.4.0.tar.gz: java/awt/dnd/DragSourceDragEvent.h <==
// public class java.awt.dnd.DragSourceDragEvent

// class file dependencies
// @dep_class 3ff6e556773b1ec6 java_awt_dnd_DragSourceDragEvent
// @dep_class 8fa38a35dead9728 java_awt_dnd_DragSourceEvent
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_awt_dnd_DragSourceEvent

#include "java/awt/dnd/DragSourceEvent.h"

#ifndef _JC_java_awt_dnd_DragSourceDragEvent_H_
#define _JC_java_awt_dnd_DragSourceDragEvent_H_

// Forward structure declarations
struct _jc_java_awt_dnd_DragSourceContext$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_dnd_DragSourceDragEvent$sub_refs	_jc_java_awt_dnd_DragSourceDragEvent$sub_refs;
typedef struct _jc_java_awt_dnd_DragSourceDragEvent$sub_nonrefs	_jc_java_awt_dnd_DragSourceDragEvent$sub_nonrefs;
typedef struct _jc_java_awt_dnd_DragSourceDragEvent$refs	_jc_java_awt_dnd_DragSourceDragEvent$refs;
typedef struct _jc_java_awt_dnd_DragSourceDragEvent$nonrefs	_jc_java_awt_dnd_DragSourceDragEvent$nonrefs;
typedef struct _jc_java_awt_dnd_DragSourceDragEvent$object	_jc_java_awt_dnd_DragSourceDragEvent$object;

typedef struct _jc_java_awt_dnd_DragSourceDragEvent$fields_struct	_jc_java_awt_dnd_DragSourceDragEvent$fields_struct;
typedef const struct _jc_java_awt_dnd_DragSourceDragEvent$vmethods	_jc_java_awt_dnd_DragSourceDragEvent$vmethods;
typedef const struct _jc_java_awt_dnd_DragSourceDragEvent$vtable	_jc_java_awt_dnd_DragSourceDragEvent$vtable;
typedef const struct _jc_java_awt_dnd_DragSourceDragEvent$vtype	_jc_java_awt_dnd_DragSourceDragEvent$vtype;

// Class fields structure
struct _jc_java_awt_dnd_DragSourceDragEvent$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_dnd_DragSourceDragEvent$fields_struct _jc_java_awt_dnd_DragSourceDragEvent$class_fields;

// Constructors
extern void _jc_java_awt_dnd_DragSourceDragEvent$method$_init$bb959ce89c23a485(_jc_env *, struct _jc_java_awt_dnd_DragSourceDragEvent$object *, struct _jc_java_awt_dnd_DragSourceContext$object *, jint, jint, jint);
extern void _jc_java_awt_dnd_DragSourceDragEvent$method$_init$4a0e259fb4336157(_jc_env *, struct _jc_java_awt_dnd_DragSourceDragEvent$object *, struct _jc_java_awt_dnd_DragSourceContext$object *, jint, jint, jint, jint, jint);

// Virtual methods
extern jint _jc_java_awt_dnd_DragSourceDragEvent$method$getDropAction$edda4aeecf125b6a(_jc_env *, struct _jc_java_awt_dnd_DragSourceDragEvent$object *);
extern jint _jc_java_awt_dnd_DragSourceDragEvent$method$getGestureModifiers$74a3f639f2ebbd19(_jc_env *, struct _jc_java_awt_dnd_DragSourceDragEvent$object *);
extern jint _jc_java_awt_dnd_DragSourceDragEvent$method$getGestureModifiersEx$88ee0566aed6a90a(_jc_env *, struct _jc_java_awt_dnd_DragSourceDragEvent$object *);
extern jint _jc_java_awt_dnd_DragSourceDragEvent$method$getTargetActions$f714e1d7abe92ccf(_jc_env *, struct _jc_java_awt_dnd_DragSourceDragEvent$object *);
extern jint _jc_java_awt_dnd_DragSourceDragEvent$method$getUserAction$1a27e6f382fc4540(_jc_env *, struct _jc_java_awt_dnd_DragSourceDragEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_dnd_DragSourceDragEvent$method_info$getDropAction$edda4aeecf125b6a;
extern _jc_method _jc_java_awt_dnd_DragSourceDragEvent$method_info$getGestureModifiers$74a3f639f2ebbd19;
extern _jc_method _jc_java_awt_dnd_DragSourceDragEvent$method_info$getGestureModifiersEx$88ee0566aed6a90a;
extern _jc_method _jc_java_awt_dnd_DragSourceDragEvent$method_info$getTargetActions$f714e1d7abe92ccf;
extern _jc_method _jc_java_awt_dnd_DragSourceDragEvent$method_info$getUserAction$1a27e6f382fc4540;

// Virtual methods structure
struct _jc_java_awt_dnd_DragSourceDragEvent$vmethods {
	jint	(*getDropAction$edda4aeecf125b6a)(_jc_env *, struct _jc_java_awt_dnd_DragSourceDragEvent$object *);
	jint	(*getGestureModifiers$74a3f639f2ebbd19)(_jc_env *, struct _jc_java_awt_dnd_DragSourceDragEvent$object *);
	jint	(*getGestureModifiersEx$88ee0566aed6a90a)(_jc_env *, struct _jc_java_awt_dnd_DragSourceDragEvent$object *);
	jint	(*getTargetActions$f714e1d7abe92ccf)(_jc_env *, struct _jc_java_awt_dnd_DragSourceDragEvent$object *);
	jint	(*getUserAction$1a27e6f382fc4540)(_jc_env *, struct _jc_java_awt_dnd_DragSourceDragEvent$object *);
};

// Vtable
struct _jc_java_awt_dnd_DragSourceDragEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_awt_dnd_DragSourceEvent$vmethods	java_awt_dnd_DragSourceEvent;
	_jc_java_awt_dnd_DragSourceDragEvent$vmethods	java_awt_dnd_DragSourceDragEvent;
};

// Vtype
struct _jc_java_awt_dnd_DragSourceDragEvent$vtype {
	_jc_type			type;
	_jc_java_awt_dnd_DragSourceDragEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_dnd_DragSourceDragEvent$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_dnd_DragSourceDragEvent$refs {
    _jc_java_awt_dnd_DragSourceDragEvent$sub_refs	java_awt_dnd_DragSourceDragEvent;
    _jc_java_awt_dnd_DragSourceEvent$sub_refs	java_awt_dnd_DragSourceEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_dnd_DragSourceDragEvent$sub_nonrefs {
	jint	dropAction;
	jint	targetActions;
	jint	gestureModifiers;
};

// Non-reference instance fields (object)
struct _jc_java_awt_dnd_DragSourceDragEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_awt_dnd_DragSourceEvent$sub_nonrefs	java_awt_dnd_DragSourceEvent;
    _jc_java_awt_dnd_DragSourceDragEvent$sub_nonrefs	java_awt_dnd_DragSourceDragEvent;
};

// Object instance structure
struct _jc_java_awt_dnd_DragSourceDragEvent$object {
	_jc_java_awt_dnd_DragSourceDragEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_dnd_DragSourceDragEvent$vtype	*vtype;
	_jc_java_awt_dnd_DragSourceDragEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_dnd_DragSourceDragEvent$vtype _jc_java_awt_dnd_DragSourceDragEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_dnd_DragSourceDragEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_dnd_DragSourceDragEvent$class_object;

#endif	/* _JC_java_awt_dnd_DragSourceDragEvent_H_ */

==> jc-1.4.6.tar.gz: java/awt/dnd/DragSourceDragEvent.h <==
// public class java.awt.dnd.DragSourceDragEvent

// class file dependencies
// @dep_class 3ff6e556773b1ec6 java_awt_dnd_DragSourceDragEvent
// @dep_class 8fa38a35dead9728 java_awt_dnd_DragSourceEvent
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_awt_dnd_DragSourceEvent

#include "java/awt/dnd/DragSourceEvent.h"

#ifndef _JC_java_awt_dnd_DragSourceDragEvent_H_
#define _JC_java_awt_dnd_DragSourceDragEvent_H_

// Forward structure declarations
struct _jc_java_awt_dnd_DragSourceContext$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_dnd_DragSourceDragEvent$sub_refs	_jc_java_awt_dnd_DragSourceDragEvent$sub_refs;
typedef struct _jc_java_awt_dnd_DragSourceDragEvent$sub_nonrefs	_jc_java_awt_dnd_DragSourceDragEvent$sub_nonrefs;
typedef struct _jc_java_awt_dnd_DragSourceDragEvent$refs	_jc_java_awt_dnd_DragSourceDragEvent$refs;
typedef struct _jc_java_awt_dnd_DragSourceDragEvent$nonrefs	_jc_java_awt_dnd_DragSourceDragEvent$nonrefs;
typedef struct _jc_java_awt_dnd_DragSourceDragEvent$object	_jc_java_awt_dnd_DragSourceDragEvent$object;

typedef struct _jc_java_awt_dnd_DragSourceDragEvent$fields_struct	_jc_java_awt_dnd_DragSourceDragEvent$fields_struct;
typedef const struct _jc_java_awt_dnd_DragSourceDragEvent$vmethods	_jc_java_awt_dnd_DragSourceDragEvent$vmethods;
typedef const struct _jc_java_awt_dnd_DragSourceDragEvent$vtable	_jc_java_awt_dnd_DragSourceDragEvent$vtable;
typedef const struct _jc_java_awt_dnd_DragSourceDragEvent$vtype	_jc_java_awt_dnd_DragSourceDragEvent$vtype;

// Class fields structure
struct _jc_java_awt_dnd_DragSourceDragEvent$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_dnd_DragSourceDragEvent$fields_struct _jc_java_awt_dnd_DragSourceDragEvent$class_fields;

// Constructors
extern void _jc_java_awt_dnd_DragSourceDragEvent$method$_init$bb959ce89c23a485(_jc_env *, struct _jc_java_awt_dnd_DragSourceDragEvent$object *, struct _jc_java_awt_dnd_DragSourceContext$object *, jint, jint, jint) _JC_JCNI_ATTR;
extern void _jc_java_awt_dnd_DragSourceDragEvent$method$_init$4a0e259fb4336157(_jc_env *, struct _jc_java_awt_dnd_DragSourceDragEvent$object *, struct _jc_java_awt_dnd_DragSourceContext$object *, jint, jint, jint, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_java_awt_dnd_DragSourceDragEvent$method$getDropAction$edda4aeecf125b6a(_jc_env *, struct _jc_java_awt_dnd_DragSourceDragEvent$object *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_dnd_DragSourceDragEvent$method$getGestureModifiers$74a3f639f2ebbd19(_jc_env *, struct _jc_java_awt_dnd_DragSourceDragEvent$object *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_dnd_DragSourceDragEvent$method$getGestureModifiersEx$88ee0566aed6a90a(_jc_env *, struct _jc_java_awt_dnd_DragSourceDragEvent$object *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_dnd_DragSourceDragEvent$method$getTargetActions$f714e1d7abe92ccf(_jc_env *, struct _jc_java_awt_dnd_DragSourceDragEvent$object *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_dnd_DragSourceDragEvent$method$getUserAction$1a27e6f382fc4540(_jc_env *, struct _jc_java_awt_dnd_DragSourceDragEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_dnd_DragSourceDragEvent$method_info$getDropAction$edda4aeecf125b6a;
extern _jc_method _jc_java_awt_dnd_DragSourceDragEvent$method_info$getGestureModifiers$74a3f639f2ebbd19;
extern _jc_method _jc_java_awt_dnd_DragSourceDragEvent$method_info$getGestureModifiersEx$88ee0566aed6a90a;
extern _jc_method _jc_java_awt_dnd_DragSourceDragEvent$method_info$getTargetActions$f714e1d7abe92ccf;
extern _jc_method _jc_java_awt_dnd_DragSourceDragEvent$method_info$getUserAction$1a27e6f382fc4540;

// Virtual methods structure
struct _jc_java_awt_dnd_DragSourceDragEvent$vmethods {
	jint	(*getDropAction$edda4aeecf125b6a)(_jc_env *, struct _jc_java_awt_dnd_DragSourceDragEvent$object *) _JC_JCNI_ATTR;
	jint	(*getGestureModifiers$74a3f639f2ebbd19)(_jc_env *, struct _jc_java_awt_dnd_DragSourceDragEvent$object *) _JC_JCNI_ATTR;
	jint	(*getGestureModifiersEx$88ee0566aed6a90a)(_jc_env *, struct _jc_java_awt_dnd_DragSourceDragEvent$object *) _JC_JCNI_ATTR;
	jint	(*getTargetActions$f714e1d7abe92ccf)(_jc_env *, struct _jc_java_awt_dnd_DragSourceDragEvent$object *) _JC_JCNI_ATTR;
	jint	(*getUserAction$1a27e6f382fc4540)(_jc_env *, struct _jc_java_awt_dnd_DragSourceDragEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_dnd_DragSourceDragEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_awt_dnd_DragSourceEvent$vmethods	java_awt_dnd_DragSourceEvent;
	_jc_java_awt_dnd_DragSourceDragEvent$vmethods	java_awt_dnd_DragSourceDragEvent;
};

// Vtype
struct _jc_java_awt_dnd_DragSourceDragEvent$vtype {
	_jc_type			type;
	_jc_java_awt_dnd_DragSourceDragEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_dnd_DragSourceDragEvent$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_dnd_DragSourceDragEvent$refs {
    _jc_java_awt_dnd_DragSourceDragEvent$sub_refs	java_awt_dnd_DragSourceDragEvent;
    _jc_java_awt_dnd_DragSourceEvent$sub_refs	java_awt_dnd_DragSourceEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_dnd_DragSourceDragEvent$sub_nonrefs {
	jint	dropAction;
	jint	targetActions;
	jint	gestureModifiers;
};

// Non-reference instance fields (object)
struct _jc_java_awt_dnd_DragSourceDragEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_awt_dnd_DragSourceEvent$sub_nonrefs	java_awt_dnd_DragSourceEvent;
    _jc_java_awt_dnd_DragSourceDragEvent$sub_nonrefs	java_awt_dnd_DragSourceDragEvent;
};

// Object instance structure
struct _jc_java_awt_dnd_DragSourceDragEvent$object {
	_jc_java_awt_dnd_DragSourceDragEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_dnd_DragSourceDragEvent$vtype	*vtype;
	_jc_java_awt_dnd_DragSourceDragEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_dnd_DragSourceDragEvent$vtype _jc_java_awt_dnd_DragSourceDragEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_dnd_DragSourceDragEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_dnd_DragSourceDragEvent$class_object;

#endif	/* _JC_java_awt_dnd_DragSourceDragEvent_H_ */
